<div class="container text-center text-secondary fs-6">
    <span class="small">Visualizations powered by PyGWalker: <a href="https://github.com/Kanaries/pygwalker" target="_blank">https://github.com/Kanaries/pygwalker</a></span>
</div>