{% extends BASE_TEMPLATE|default:"base.htm" %}

{% block content %}
<section class="animated fadeIn" style="animation-delay: .15s;">
    {% include "pygwalker/bs5/partials/header.htm" %}
</section>
<section class="animated fadeIn" style="animation-delay: .25s;">
    {% include "pygwalker/bs5/partials/pyg.htm" %}
</section>
<section class="animated fadeIn" style="animation-delay: .35s;">
    {% include "pygwalker/bs5/partials/footer.htm" %}
</section>
{% endblock content %}
