    <header class="m-5">
        <div class="headline text-center">
            <div class="container">
                <div class="h1 text-primary fw-bold mb-3">{{ title|safe }}</div>
            </div>
        </div>
    </header>