<div class="container text-center">
    <form method="post" enctype="multipart/form-data">
        {% csrf_token %}
        <div class="form-group row">
            <div class="col-10 col-md-11">
                <input type="file" class="form-control" name="csv_file" required id="id_csv_file">
            </div>
            <div class="col-2 col-md-1">
                <button type="submit" class="btn btn-primary btn-block">Upload</button>
            </div>
        </div>
    </form>
</div>